@@ -1,6 +1,7 @@
 .fittedW <- function(p,q,fit){ 
   l <- log(q+1)
-  data=data.frame(cbind(p,l))
+  c <- c(rep(1,length(p)))
+  data=data.frame(cbind(p,l,c))
   w_fit <- predict(fit,data)
   return(w_fit)
 }
\ No newline at end of file
